@@ -1,8 +1,7 @@
 from . import APP_NAME
-from .view import DemoView, LoginView
+from .view import DemoView
 from core.base_view import path
 
 urlpatterns = [
     path('/user', DemoView, tags=[APP_NAME]),
-    path('/login', LoginView, tags=[APP_NAME])
 ]
