@@ -8,8 +8,10 @@ from typing import Union, Type
 from fastapi import APIRouter, Depends
 
 from auth.base_authentication import BaseTokenAuthentication
+from config.settings import CREATE_DEPENDS_SESSION
 from core.context import g
 
+
 base_router = APIRouter()
 
 
@@ -37,6 +39,28 @@ class BaseView:
     def user_id(self):
         return g.user.id
 
+    def get_dependencies(self, extra_params: dict, method):
+        custom_permission_classes = extra_params.pop('permission_classes', None)
+        custom_authentication_classes = extra_params.pop('authentication_classes', None)
+        authentication_classes = (custom_authentication_classes if custom_authentication_classes is not None
+                                  else self.authentication_classes)
+        permission_classes = (custom_permission_classes if custom_permission_classes is not None else
+                              self.permissions_classes)
+        dependencies = [Depends(_(name='')(method)) for _ in authentication_classes] + \
+                       [Depends(_(method)) for _ in permission_classes]
+        depend_session: bool = extra_params.pop("depend_session", CREATE_DEPENDS_SESSION)
+        if depend_session:
+            try:
+                from db.database import sessionmanager
+            except ImportError:
+                pass
+            else:
+                if inspect.iscoroutinefunction(method):
+                    dependencies.insert(0, Depends(sessionmanager.get_db))
+                else:
+                    dependencies.insert(0, Depends(sessionmanager.get_db_sync))
+        return dependencies
+
     def register_routes(self):
         resource_id = "/{" + self.resource_id + "}"
         method_map = {
@@ -53,14 +77,10 @@ class BaseView:
             method = getattr(self, method_name, None)
             if self.is_method_overridden(method_name):
                 extra_params = getattr(method, '_extra_params', {})
-                custom_permission_classes = extra_params.pop('permission_classes', None)
-                custom_authentication_classes = extra_params.pop('authentication_classes', None)
-                authentication_classes = custom_authentication_classes if custom_authentication_classes is not None else self.authentication_classes
-                permission_classes = custom_permission_classes if custom_permission_classes is not None else self.permissions_classes
-                dependencies = authentication_classes + permission_classes
+                dependencies = self.get_dependencies(extra_params, method)
                 base_router.add_api_route(router_info['path'], method,
                                           methods=router_info['methods'],
-                                          dependencies=[Depends(_(method)) for _ in dependencies],
+                                          dependencies=dependencies,
                                           tags=self.tags, **extra_params)
 
     def is_method_overridden(self, method_name: str) -> bool:
@@ -72,7 +92,7 @@ class BaseView:
         return inspect.getmodule(subclass_method) != inspect.getmodule(base_method)
 
     @staticmethod
-    def message(code: int = 0, message: str = 'success', data: Union[dict, None, list, str] = None):
+    def response(code: int = 0, message: str = 'success', data: Union[dict, None, list, str] = None):
         return {
             "code": code,
             "message": message,
