@@ -2,7 +2,9 @@
 # @Time : 2024/6/6 10:41
 # @Author : PinBar
 # @File : example.py
-from fastapi import Request
+from typing import Annotated
+
+from fastapi import Body, Form, Query
 
 from core.base_view import BaseView
 from core.decorator import api_description
